@@ -29,34 +29,22 @@ class TableData:
         return results
 
     @classmethod
-    def make_individu(cls, data: str) -> List["TableData"]:
+    def makes(
+        cls,
+        data: str,
+        locate: str,
+        offset: int = 1,
+        lstrip: str = "",
+        rstrip: str = "",
+    ):
         tabledata: str = ""
         datas = data.splitlines()
         for i, line in enumerate(datas):
-            if "/*individu*/" in line:
-                tabledata = datas[i + 1]
+            if locate in line:
+                tabledata = datas[i + offset]
                 tabledata = tabledata.strip()
-                tabledata = tabledata.lstrip("try {var tabledata = ")
-                tabledata = tabledata.rstrip(
-                    ';putTable("#fit_individu",tabledata);} catch(err) {  };'
-                )
-                break
-        if not tabledata:
-            return list()
-        return cls.from_json5_list(tabledata)
-
-    @classmethod
-    def make_status_nuptk(cls, data: str) -> List["TableData"]:
-        tabledata: str = ""
-        datas = data.splitlines()
-        for i, line in enumerate(datas):
-            if "/*arsip NUPTK*/" in line:
-                tabledata = datas[i + 1]
-                tabledata = tabledata.strip()
-                tabledata = tabledata.lstrip("try { var tabledata = ")
-                tabledata = tabledata.rstrip(
-                    ';putTable("#fit_ArsipNuptk",tabledata);} catch(err) {  };'
-                )
+                tabledata = tabledata.lstrip(lstrip)
+                tabledata = tabledata.rstrip(rstrip)
                 break
         if not tabledata:
             return list()
